==> allegro-3.9.31.tar.gz: allegro-3.9.31/acconfig.h <==
/* Define if you want support for 8 bpp modes.  */
#undef ALLEGRO_COLOR8

/* Define if you want support for 16 bpp modes.  */
#undef ALLEGRO_COLOR16

/* Define if you want support for 24 bpp modes.  */
#undef ALLEGRO_COLOR24

/* Define if you want support for 32 bpp modes.  */
#undef ALLEGRO_COLOR32

/* Define if compiler prepends underscore to symbols.  */
#undef ALLEGRO_ASM_PREFIX

/* Define if assembler supports MMX.  */
#undef ALLEGRO_MMX

/* Define for Unix platforms, to use C convention for bank switching.  */
#undef ALLEGRO_NO_ASM

/* Define if target platform is linux.  */
#undef ALLEGRO_LINUX

/* Define to enable Linux console VGA driver */
#undef ALLEGRO_LINUX_VGA

/* Define to enable Linux console fbcon driver */
#undef ALLEGRO_LINUX_FBCON

/* Define to enable Linux console VBE/AF driver */
#undef ALLEGRO_LINUX_VBEAF

/* Define to enable Linux console GGI driver */
#undef ALLEGRO_LINUX_GGI

/* Define to enable Linux console SVGAlib driver */
#undef ALLEGRO_LINUX_SVGALIB

/* Define if target machine is little endian.  */
#undef ALLEGRO_LITTLE_ENDIAN

/* Define if target machine is big endian.  */
#undef ALLEGRO_BIG_ENDIAN

/* Define if you need support for X-Windows.  */
#undef ALLEGRO_WITH_XWINDOWS

/* Define if MIT-SHM extension is supported.  */
#undef ALLEGRO_XWINDOWS_WITH_SHM

/* Define if XF86DGA extension is supported.  */
#undef ALLEGRO_XWINDOWS_WITH_XF86DGA

/* Define if OSS DIGI driver is supported.  */
#undef ALLEGRO_WITH_OSSDIGI

/* Define if OSS MIDI driver is supported.  */
#undef ALLEGRO_WITH_OSSMIDI

/* Define if ALSA DIGI driver is supported.  */
#undef ALLEGRO_WITH_ALSADIGI

/* Define if ESD DIGI driver is supported.  */
#undef ALLEGRO_WITH_ESDDIGI

/* Define to (void *)-1, if MAP_FAILED is not defined.  */
#undef MAP_FAILED

/* Define if constructor attribute is supported. */
#undef ALLEGRO_USE_CONSTRUCTOR

==> allegro4_4.0.1.orig.tar.gz: allegro-4.0.1/acconfig.h <==
/* Define if you want support for 8 bpp modes.  */
#undef ALLEGRO_COLOR8

/* Define if you want support for 16 bpp modes.  */
#undef ALLEGRO_COLOR16

/* Define if you want support for 24 bpp modes.  */
#undef ALLEGRO_COLOR24

/* Define if you want support for 32 bpp modes.  */
#undef ALLEGRO_COLOR32

/* Define if compiler prepends underscore to symbols.  */
#undef ALLEGRO_ASM_PREFIX

/* Define if assembler supports MMX.  */
#undef ALLEGRO_MMX

/* Define if assembler supports SSE.  */
#undef ALLEGRO_SSE

/* Define for Unix platforms, to use C convention for bank switching.  */
#undef ALLEGRO_NO_ASM

/* Define if target platform is linux.  */
#undef ALLEGRO_LINUX

/* Define to enable Linux console VGA driver */
#undef ALLEGRO_LINUX_VGA

/* Define to enable Linux console fbcon driver */
#undef ALLEGRO_LINUX_FBCON

/* Define to enable Linux console VBE/AF driver */
#undef ALLEGRO_LINUX_VBEAF

/* Define to enable Linux console SVGAlib driver */
#undef ALLEGRO_LINUX_SVGALIB

/* Define if SVGAlib driver can check vga_version */
#undef ALLEGRO_LINUX_SVGALIB_HAVE_VGA_VERSION

/* Define if target machine is little endian.  */
#undef ALLEGRO_LITTLE_ENDIAN

/* Define if target machine is big endian.  */
#undef ALLEGRO_BIG_ENDIAN

/* Define if dynamically loaded modules are supported.  */
#undef ALLEGRO_WITH_MODULES

/* Define if you need support for X-Windows.  */
#undef ALLEGRO_WITH_XWINDOWS

/* Define if MIT-SHM extension is supported.  */
#undef ALLEGRO_XWINDOWS_WITH_SHM

/* Define if XF86VidMode extension is supported.  */
#undef ALLEGRO_XWINDOWS_WITH_XF86VIDMODE

/* Define if XF86DGA extension is supported.  */
#undef ALLEGRO_XWINDOWS_WITH_XF86DGA

/* Define if DGA version 2.0 or newer is supported */
#undef ALLEGRO_XWINDOWS_WITH_XF86DGA2

/* Define if OSS DIGI driver is supported.  */
#undef ALLEGRO_WITH_OSSDIGI

/* Define if OSS MIDI driver is supported.  */
#undef ALLEGRO_WITH_OSSMIDI

/* Define if ALSA DIGI driver is supported.  */
#undef ALLEGRO_WITH_ALSADIGI

/* Define if ALSA MIDI driver is supported.  */
#undef ALLEGRO_WITH_ALSAMIDI

/* Define if ESD DIGI driver is supported.  */
#undef ALLEGRO_WITH_ESDDIGI

/* Define to (void *)-1, if MAP_FAILED is not defined.  */
#undef MAP_FAILED

/* Define if constructor attribute is supported. */
#undef ALLEGRO_USE_CONSTRUCTOR

/* Define if sched_yield is provided by some library.  */
#undef ALLEGRO_USE_SCHED_YIELD
